Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(204)

Unified Diff: ash/root_window_controller.h

Issue 2648483002: chromeos: Rename various CreateShelf methods to CreateShelfView (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/root_window_controller.h
diff --git a/ash/root_window_controller.h b/ash/root_window_controller.h
index 56610f579824e732d77ccd71f7ee214f6cc66dbd..30f7ec08240d2a9786ac08700be270d5bffc9655 100644
--- a/ash/root_window_controller.h
+++ b/ash/root_window_controller.h
@@ -144,8 +144,8 @@ class ASH_EXPORT RootWindowController : public ShellObserver {
WmShelf* GetShelf();
- // Creates the shelf for this root window and notifies observers.
- void CreateShelf();
+ // Creates the shelf view for this root window and notifies observers.
+ void CreateShelfView();
// Get touch HUDs associated with this root window controller.
TouchHudDebug* touch_hud_debug() const { return touch_hud_debug_; }

Powered by Google App Engine
This is Rietveld 408576698